﻿namespace histcopy
{
    internal class Program
    {
        static void Main(string[] arguments)
        {
            Console.WriteLine("histcopy version 2.02 (2024-10-07) (c)2002-2024 North Innovations");

            var verifyCycle = 100.0;
            var directoryNames = new List<string>();
            try
            {
                for (var index = 0; index < arguments.Length; index++)
                {
                    var argument = arguments[index];
                    if (argument.Contains('"'))
                    {
                        Console.WriteLine("A backslash (\\) is escape character. Please modify as below.");
                        var pathName = $"{argument[..argument.IndexOf('"')]}\\";
                        Console.WriteLine($"- Add a backslash.      \"{pathName}\" -> \"{pathName}\\\"");
                        if (pathName.Length > 3)
                            Console.WriteLine($"- Remove the backslash. \"{pathName}\" -> \"{pathName[..^1]}\"");
                        if (!pathName.Contains(' '))
                            Console.WriteLine($"- Remove the quotes.    \"{pathName}\" -> {pathName}");
                        return;
                    }
                    switch (argument)
                    {
                        case "-verify-cycle": verifyCycle = double.Parse(arguments[++index]); break;
                        default: directoryNames.Add(argument); break;
                    }
                }
                if (directoryNames.Count != 2)
                    throw new Exception();
            }
            catch
            {
                Console.WriteLine("usage: histcopy <source> <destination> [options...]");
                Console.WriteLine("default: -verify-cycle 100");
                return;
            }

            try
            {
                var source = new CancellationTokenSource();
                var copy = new Histcopy(directoryNames[0], directoryNames[1], source.Token) {
                    VerifyCycle = verifyCycle
                };
                copy.Progress += (s, e) => Console.WriteLine(e.Message);
                Console.CancelKeyPress += (s, e) => {
                    e.Cancel = true;
                    source.Cancel();
                    Console.Write("^C");
                };
                copy.Run();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
